@@ -37,7 +37,7 @@ class SoftmaxLocallyHook(BaseWrapperHook):
         Arguments:
             apply_to: list of names of tensors that softmax
                 will be applied to.
-            hooks: the hooks that will receive the softmaxed
+            *hooks: the hooks that will receive the softmaxed
                 tensors.
         """
         super().__init__(**kwargs)
@@ -130,3 +130,19 @@ class FinetunerHook(ClassifierHook):
         f_hook = FrozenModelHook(FeaturesHook(detach=True, domains=["src"]), "G")
         f_hook = FeaturesChainHook(f_hook, LogitsHook(domains=["src"]))
         super().__init__(f_hook=f_hook, **kwargs)
+
+
+# labels are usually int
+class BCEWithLogitsConvertLabels(torch.nn.BCEWithLogitsLoss):
+    def forward(self, input, target, *args, **kwargs):
+        return super().forward(input, target.float(), *args, **kwargs)
+
+
+class MultiLabelClassifierHook(ClassifierHook):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, loss_fn=BCEWithLogitsConvertLabels(), **kwargs)
+
+
+class MultiLabelFinetunerHook(FinetunerHook):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, loss_fn=BCEWithLogitsConvertLabels(), **kwargs)
